"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.signTypedData = signTypedData;
exports.signTypedDataForSession = signTypedDataForSession;
const viem_1 = require("viem");
const actions_1 = require("viem/actions");
const utils_1 = require("viem/utils");
const AGWAccount_js_1 = require("../abis/AGWAccount.js");
const constants_js_1 = require("../constants.js");
const getAgwTypedSignature_js_1 = require("../getAgwTypedSignature.js");
const sessions_js_1 = require("../sessions.js");
const utils_js_1 = require("../utils.js");
const sendPrivyTransaction_js_1 = require("./sendPrivyTransaction.js");
const signTransaction_js_1 = require("./signTransaction.js");
async function signTypedData(client, signerClient, parameters, isPrivyCrossApp = false) {
    if (isPrivyCrossApp)
        return await (0, sendPrivyTransaction_js_1.sendPrivySignTypedData)(client, parameters);
    if ((0, utils_js_1.isEip712TypedData)(parameters)) {
        const rawSignature = await (0, actions_1.signTypedData)(signerClient, parameters);
        const hookData = [];
        const validationHooks = await (0, utils_1.getAction)(client, actions_1.readContract, 'readContract')({
            address: client.account.address,
            abi: AGWAccount_js_1.default,
            functionName: 'listHooks',
            args: [true],
        });
        for (const _ of validationHooks) {
            hookData.push('0x');
        }
        const signature = (0, viem_1.encodeAbiParameters)((0, viem_1.parseAbiParameters)(['bytes', 'address', 'bytes[]']), [rawSignature, constants_js_1.EOA_VALIDATOR_ADDRESS, hookData]);
        return signature;
    }
    return await (0, getAgwTypedSignature_js_1.getAgwTypedSignature)({
        client,
        signer: signerClient,
        messageHash: (0, viem_1.hashTypedData)(parameters),
    });
}
async function signTypedDataForSession(client, signerClient, parameters, session, paymasterHandler) {
    if (!(0, utils_js_1.isEip712TypedData)(parameters)) {
        throw new viem_1.BaseError('Session client can only sign EIP712 transactions as typed data');
    }
    const transactionRequest = (0, utils_js_1.transformEip712TypedData)(parameters);
    if (!transactionRequest.to) {
        throw new viem_1.BaseError('Transaction must have a to address');
    }
    const validationHookData = {
        [constants_js_1.SESSION_KEY_VALIDATOR_ADDRESS]: (0, sessions_js_1.encodeSessionWithPeriodIds)(session, (0, sessions_js_1.getPeriodIdsForTransaction)({
            sessionConfig: session,
            target: transactionRequest.to,
            selector: (transactionRequest.data?.slice(0, 10) ?? '0x'),
            timestamp: BigInt(Math.floor(Date.now() / 1000)),
        })),
    };
    const { customSignature } = await (0, signTransaction_js_1.signEip712TransactionInternal)(client, signerClient, {
        chain: client.chain,
        ...transactionRequest,
    }, constants_js_1.SESSION_KEY_VALIDATOR_ADDRESS, false, validationHookData, paymasterHandler);
    return customSignature;
}
//# sourceMappingURL=signTypedData.js.map