"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.toSessionClient = toSessionClient;
exports.createSessionClient = createSessionClient;
const viem_1 = require("viem");
const accounts_1 = require("viem/accounts");
const walletActions_js_1 = require("./walletActions.js");
function toSessionClient({ client, signer, session, paymasterHandler, }) {
    return createSessionClient({
        account: client.account,
        chain: client.chain,
        session,
        signer,
        transport: (0, viem_1.custom)(client.transport),
        paymasterHandler,
    });
}
function createSessionClient({ account, signer, chain, transport, session, paymasterHandler, }) {
    if (!transport) {
        transport = (0, viem_1.http)();
    }
    const publicClient = (0, viem_1.createPublicClient)({
        transport: (0, viem_1.http)(),
        chain,
    });
    const baseClient = (0, viem_1.createClient)({
        account: typeof account === 'string' ? (0, accounts_1.toAccount)(account) : account,
        chain: chain,
        transport,
    });
    const signerWalletClient = (0, viem_1.createWalletClient)({
        account: signer,
        chain: chain,
        transport,
    });
    const sessionClient = baseClient.extend((0, walletActions_js_1.sessionWalletActions)(signerWalletClient, publicClient, session, paymasterHandler));
    return sessionClient;
}
//# sourceMappingURL=sessionClient.js.map