import { type Account, type Address, type Client, type Transport } from 'viem';
import { type ChainEIP712 } from 'viem/zksync';
import { type AbstractWalletActions } from './walletActions.js';
/**
 * Parameters for creating an AbstractClient instance.
 * @interface CreateAbstractClientParameters
 */
interface CreateAbstractClientParameters {
    /**
     * The account used for signing AGW transactions.
     * @type {Account}
     */
    signer: Account;
    /**
     * The chain configuration supporting EIP-712.
     * @type {ChainEIP712}
     */
    chain: ChainEIP712;
    /**
     * Optional transport layer for network communication.
     * If not provided, a default HTTP transport will be used.
     * @type {Transport}
     * @optional
     */
    transport?: Transport;
    address?: Address;
    isPrivyCrossApp?: boolean;
}
type AbstractClientActions = AbstractWalletActions<ChainEIP712, Account>;
export type AbstractClient = Client<Transport, ChainEIP712, Account> & AbstractClientActions;
export declare function createAbstractClient({ signer, chain, transport, address, isPrivyCrossApp, }: CreateAbstractClientParameters): Promise<AbstractClient>;
export {};
//# sourceMappingURL=abstractClient.d.ts.map