import { type Account, type Address, type Client, type Hex, type Transport, type UnionRequiredBy, type WalletClient } from 'viem';
import { type ChainEIP712, type SignEip712TransactionParameters, type SignEip712TransactionReturnType, type TransactionRequestEIP712 } from 'viem/zksync';
export interface CustomPaymasterParameters {
    nonce: number;
    from: Address;
    to: Address;
    gas: bigint;
    gasPrice: bigint;
    gasPerPubdata: bigint;
    value: bigint;
    data: Hex | undefined;
    maxFeePerGas: bigint;
    maxPriorityFeePerGas: bigint;
    chainId: number;
}
export type CustomPaymasterHandler = (args: CustomPaymasterParameters) => Promise<{
    paymaster: Address;
    paymasterInput: Hex;
}>;
export declare function signTransaction<chain extends ChainEIP712 | undefined = ChainEIP712 | undefined, account extends Account | undefined = Account | undefined, chainOverride extends ChainEIP712 | undefined = ChainEIP712 | undefined>(client: Client<Transport, ChainEIP712, Account>, signerClient: WalletClient<Transport, ChainEIP712, Account>, args: SignEip712TransactionParameters<chain, account, chainOverride>, validator: Address, useSignerAddress?: boolean, validationHookData?: Record<string, Hex>, customPaymasterHandler?: CustomPaymasterHandler | undefined): Promise<SignEip712TransactionReturnType>;
export declare function signEip712TransactionInternal<chain extends ChainEIP712 | undefined = ChainEIP712 | undefined, account extends Account | undefined = Account | undefined, chainOverride extends ChainEIP712 | undefined = ChainEIP712 | undefined>(client: Client<Transport, ChainEIP712, Account>, signerClient: WalletClient<Transport, ChainEIP712, Account>, args: SignEip712TransactionParameters<chain, account, chainOverride>, validator: Address, useSignerAddress?: boolean, validationHookData?: Record<string, Hex>, customPaymasterHandler?: CustomPaymasterHandler | undefined): Promise<{
    transaction: UnionRequiredBy<TransactionRequestEIP712, 'from'> & {
        chainId: number;
    };
    customSignature: Hex;
}>;
//# sourceMappingURL=signTransaction.d.ts.map